#!/bin/bash
#
# $Id: libera-utca.sh 17623 2012-09-05 07:58:09Z damijan.skvarc $
#
# uTCA tool
#
# Copyright (C) 2008 Instrumentation Technologies
#

NAME=libera-utca

# timeouts
fpga_boot_timeout=30
board_deac_timeout=15

# activate board
board_act() {
	let fru=$2+4
	if [ $1 -eq 0 ];
        then
		echo "Deactivating AMC board $2"
		ipmitool -I lan -H 192.168.77.1 -P "nat" -T 0x82 -t 0x20 -b 7 picmg deactivate $fru
	else
                echo "Activation AMC board $2"
		ipmitool -I lan -H 192.168.77.1 -P "nat" -T 0x82 -t 0x20 -b 7 picmg activate $fru
	fi
}

# Activate/deactivate all slave boards
slave_boards_act() {
        for slot in {2..12}
        do
           board_act $1 $slot
        done
}

# Deactivate CPU board
cpu_board_act() {
	echo "Shuting down CPU"
	board_act 0 1
}

# System cold reset
mch_reset() {
	echo "MCH reset"
	ipmitool -I lan -H 192.168.77.1 -P "nat" -T 0x82 -t 0x20 -b 7 mc reset cold
}

# Sleep[s]
sleep_s() {
	echo "Wait $1 seconds.."
	sleep $1
}

case "$1" in
  # safe system shutdown
  shutdown)
	echo "Trying to shutdown all AMC slave boards."
	slave_boards_act 0
	sleep_s $board_deac_timeout
	echo "IMPORTANT NOTICE TO PREVENT SYSTEM DAMAGE:"
	echo "Blue LED on CPU will blink during system shutdown."
	echo "Notice that it is safe to remove power, when this led stops blinking / starts glowing!"
        cpu_board_act 0
	;;
  # safe system reset
  restart)
	# should we also reset PCIe switch here ?
	echo "Trying to restart all AMC slave boards."
	slave_boards_act 0
	sleep_s $board_deac_timeout
	slave_boards_act 1
	sleep $fpga_boot_timeout
	echo "Rebooting CPU.."
	reboot
        ;;
  # Usage  
  *)
	N=$NAME
        echo "Usage: $N {shutdown|restart}" >&2
        exit 1
        ;;
esac

exit 0
